This is a theme based on Bootstrap 4.

The theme is a good building block for a site. It is based on a simple navbar +
content layout. For a more blog-style layout, check out `bootblog4`.

Note that unlike previous versions of Bootstrap, icon fonts are not built-in.
You can use Font Awesome for this.

This theme supports Bootswatch font/color schemes through the `nikola
bootwatch_theme` command.
